import { Constructor } from "../common/types";
import { DtoFieldMetadata } from "./DtoMetadata";
import { Identifiable } from "../model/Identifiable";
import { CascadeType } from "../common/CascadeType";
import { HttpMethod } from "../http/HttpMethod";
export declare type OmitProps = "name";
declare type FieldProps = Omit<DtoFieldMetadata, OmitProps>;
/**
 * A simple data transfer object.
 */
export declare const Data: (config?: {
    /**
     * Strict:
     * - only fields in metadata are accepted
     * - strict type checking
     */
    relaxed?: boolean | undefined;
    /**
     * Description of this dto
     */
    description?: string | undefined;
    /**
     * Ignore some http method to prevent auto generation of routes and/or endpoints
     */
    ignoreCrud?: HttpMethod[] | undefined;
} | undefined) => <T extends Constructor<any>>(constructor: T) => T;
export declare const Field: (config: Partial<FieldProps>) => (prototype: any, propertyKey: string) => void;
export declare const Relation: (model: Constructor<Identifiable>, cascadeType: CascadeType) => Partial<DtoFieldMetadata>;
export declare const Enum: (enumClass: object) => Partial<DtoFieldMetadata>;
export declare const ElementDto: (dtoClass: Constructor<any>) => Partial<DtoFieldMetadata>;
export declare const HasOne: <T extends Identifiable<string | number>>(config: {
    model: Constructor<T>;
    column: keyof T;
    cascade?: CascadeType | undefined;
}) => <K extends string>(prototype: Identifiable<string | number> & Partial<Record<K, T | undefined>>, propertyKey: K) => void;
export declare const HasMany: <T extends Identifiable<string | number>>(config: {
    model: Constructor<T>;
    column: keyof T;
    cascade?: CascadeType | undefined;
}) => <K extends string>(prototype: Identifiable<string | number> & Record<K, T[]>, propertyKey: K) => void;
export {};
