export declare type PlainMessageHandler = (message: any, channel?: string) => void;
export declare type ReconnectionHandler = () => void;
export declare type DisconnectionHandler = (err?: any) => void;
export interface IClientSocket {
    /**
     * Stop receiving message
     */
    close(): void;
    /**
     * Request to listen to channels
     */
    joinChannels(channels: string[]): void;
    /**
     * Stop listening from channels
     */
    leaveChannels(channels: string[]): void;
    /**
     * Register reconnection event handler
     * @param handler reconnection handler
     */
    onReconnect(handler: ReconnectionHandler): void;
    /**
     * Register disconnection event handler
     * @param handler disconnection handler
     */
    onDisconnect(handler: DisconnectionHandler): void;
    /**
     * Send message to server
     * @param message the message payload
     * @param channel the channel to send this message to
     */
    send(message: any, channel?: string): void;
    /**
     * Register message handler
     * @param handler message handler
     */
    onMessage(handler: PlainMessageHandler): void;
}
